# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Iterator,
    Optional,
    Sequence,
    Tuple,
    Union,
)

from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.api_core import retry_async as retries_async

try:
    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault, None]
    OptionalAsyncRetry = Union[
        retries_async.AsyncRetry, gapic_v1.method._MethodDefault, None
    ]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.Retry, object, None]  # type: ignore
    OptionalAsyncRetry = Union[retries_async.AsyncRetry, object, None]  # type: ignore

from google.cloud.oracledatabase_v1.types import (
    autonomous_database,
    autonomous_database_character_set,
    autonomous_db_backup,
    autonomous_db_version,
    db_node,
    db_server,
    db_system_shape,
    entitlement,
    exadata_infra,
    gi_version,
    oracledatabase,
    vm_cluster,
)


class ListCloudExadataInfrastructuresPager:
    """A pager for iterating through ``list_cloud_exadata_infrastructures`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.oracledatabase_v1.types.ListCloudExadataInfrastructuresResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``cloud_exadata_infrastructures`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListCloudExadataInfrastructures`` requests and continue to iterate
    through the ``cloud_exadata_infrastructures`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.oracledatabase_v1.types.ListCloudExadataInfrastructuresResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., oracledatabase.ListCloudExadataInfrastructuresResponse],
        request: oracledatabase.ListCloudExadataInfrastructuresRequest,
        response: oracledatabase.ListCloudExadataInfrastructuresResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.oracledatabase_v1.types.ListCloudExadataInfrastructuresRequest):
                The initial request object.
            response (google.cloud.oracledatabase_v1.types.ListCloudExadataInfrastructuresResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = oracledatabase.ListCloudExadataInfrastructuresRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[oracledatabase.ListCloudExadataInfrastructuresResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[exadata_infra.CloudExadataInfrastructure]:
        for page in self.pages:
            yield from page.cloud_exadata_infrastructures

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListCloudVmClustersPager:
    """A pager for iterating through ``list_cloud_vm_clusters`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.oracledatabase_v1.types.ListCloudVmClustersResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``cloud_vm_clusters`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListCloudVmClusters`` requests and continue to iterate
    through the ``cloud_vm_clusters`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.oracledatabase_v1.types.ListCloudVmClustersResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., oracledatabase.ListCloudVmClustersResponse],
        request: oracledatabase.ListCloudVmClustersRequest,
        response: oracledatabase.ListCloudVmClustersResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.oracledatabase_v1.types.ListCloudVmClustersRequest):
                The initial request object.
            response (google.cloud.oracledatabase_v1.types.ListCloudVmClustersResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = oracledatabase.ListCloudVmClustersRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[oracledatabase.ListCloudVmClustersResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[vm_cluster.CloudVmCluster]:
        for page in self.pages:
            yield from page.cloud_vm_clusters

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListEntitlementsPager:
    """A pager for iterating through ``list_entitlements`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.oracledatabase_v1.types.ListEntitlementsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``entitlements`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListEntitlements`` requests and continue to iterate
    through the ``entitlements`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.oracledatabase_v1.types.ListEntitlementsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., oracledatabase.ListEntitlementsResponse],
        request: oracledatabase.ListEntitlementsRequest,
        response: oracledatabase.ListEntitlementsResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.oracledatabase_v1.types.ListEntitlementsRequest):
                The initial request object.
            response (google.cloud.oracledatabase_v1.types.ListEntitlementsResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = oracledatabase.ListEntitlementsRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[oracledatabase.ListEntitlementsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[entitlement.Entitlement]:
        for page in self.pages:
            yield from page.entitlements

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListDbServersPager:
    """A pager for iterating through ``list_db_servers`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.oracledatabase_v1.types.ListDbServersResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``db_servers`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListDbServers`` requests and continue to iterate
    through the ``db_servers`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.oracledatabase_v1.types.ListDbServersResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., oracledatabase.ListDbServersResponse],
        request: oracledatabase.ListDbServersRequest,
        response: oracledatabase.ListDbServersResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.oracledatabase_v1.types.ListDbServersRequest):
                The initial request object.
            response (google.cloud.oracledatabase_v1.types.ListDbServersResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = oracledatabase.ListDbServersRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[oracledatabase.ListDbServersResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[db_server.DbServer]:
        for page in self.pages:
            yield from page.db_servers

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListDbNodesPager:
    """A pager for iterating through ``list_db_nodes`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.oracledatabase_v1.types.ListDbNodesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``db_nodes`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListDbNodes`` requests and continue to iterate
    through the ``db_nodes`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.oracledatabase_v1.types.ListDbNodesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., oracledatabase.ListDbNodesResponse],
        request: oracledatabase.ListDbNodesRequest,
        response: oracledatabase.ListDbNodesResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.oracledatabase_v1.types.ListDbNodesRequest):
                The initial request object.
            response (google.cloud.oracledatabase_v1.types.ListDbNodesResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = oracledatabase.ListDbNodesRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[oracledatabase.ListDbNodesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[db_node.DbNode]:
        for page in self.pages:
            yield from page.db_nodes

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListGiVersionsPager:
    """A pager for iterating through ``list_gi_versions`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.oracledatabase_v1.types.ListGiVersionsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``gi_versions`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListGiVersions`` requests and continue to iterate
    through the ``gi_versions`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.oracledatabase_v1.types.ListGiVersionsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., oracledatabase.ListGiVersionsResponse],
        request: oracledatabase.ListGiVersionsRequest,
        response: oracledatabase.ListGiVersionsResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.oracledatabase_v1.types.ListGiVersionsRequest):
                The initial request object.
            response (google.cloud.oracledatabase_v1.types.ListGiVersionsResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = oracledatabase.ListGiVersionsRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[oracledatabase.ListGiVersionsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[gi_version.GiVersion]:
        for page in self.pages:
            yield from page.gi_versions

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListDbSystemShapesPager:
    """A pager for iterating through ``list_db_system_shapes`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.oracledatabase_v1.types.ListDbSystemShapesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``db_system_shapes`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListDbSystemShapes`` requests and continue to iterate
    through the ``db_system_shapes`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.oracledatabase_v1.types.ListDbSystemShapesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., oracledatabase.ListDbSystemShapesResponse],
        request: oracledatabase.ListDbSystemShapesRequest,
        response: oracledatabase.ListDbSystemShapesResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.oracledatabase_v1.types.ListDbSystemShapesRequest):
                The initial request object.
            response (google.cloud.oracledatabase_v1.types.ListDbSystemShapesResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = oracledatabase.ListDbSystemShapesRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[oracledatabase.ListDbSystemShapesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[db_system_shape.DbSystemShape]:
        for page in self.pages:
            yield from page.db_system_shapes

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListAutonomousDatabasesPager:
    """A pager for iterating through ``list_autonomous_databases`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.oracledatabase_v1.types.ListAutonomousDatabasesResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``autonomous_databases`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListAutonomousDatabases`` requests and continue to iterate
    through the ``autonomous_databases`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.oracledatabase_v1.types.ListAutonomousDatabasesResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., oracledatabase.ListAutonomousDatabasesResponse],
        request: oracledatabase.ListAutonomousDatabasesRequest,
        response: oracledatabase.ListAutonomousDatabasesResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.oracledatabase_v1.types.ListAutonomousDatabasesRequest):
                The initial request object.
            response (google.cloud.oracledatabase_v1.types.ListAutonomousDatabasesResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = oracledatabase.ListAutonomousDatabasesRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[oracledatabase.ListAutonomousDatabasesResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[autonomous_database.AutonomousDatabase]:
        for page in self.pages:
            yield from page.autonomous_databases

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListAutonomousDbVersionsPager:
    """A pager for iterating through ``list_autonomous_db_versions`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.oracledatabase_v1.types.ListAutonomousDbVersionsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``autonomous_db_versions`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListAutonomousDbVersions`` requests and continue to iterate
    through the ``autonomous_db_versions`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.oracledatabase_v1.types.ListAutonomousDbVersionsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., oracledatabase.ListAutonomousDbVersionsResponse],
        request: oracledatabase.ListAutonomousDbVersionsRequest,
        response: oracledatabase.ListAutonomousDbVersionsResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.oracledatabase_v1.types.ListAutonomousDbVersionsRequest):
                The initial request object.
            response (google.cloud.oracledatabase_v1.types.ListAutonomousDbVersionsResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = oracledatabase.ListAutonomousDbVersionsRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[oracledatabase.ListAutonomousDbVersionsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[autonomous_db_version.AutonomousDbVersion]:
        for page in self.pages:
            yield from page.autonomous_db_versions

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListAutonomousDatabaseCharacterSetsPager:
    """A pager for iterating through ``list_autonomous_database_character_sets`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.oracledatabase_v1.types.ListAutonomousDatabaseCharacterSetsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``autonomous_database_character_sets`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListAutonomousDatabaseCharacterSets`` requests and continue to iterate
    through the ``autonomous_database_character_sets`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.oracledatabase_v1.types.ListAutonomousDatabaseCharacterSetsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[
            ..., oracledatabase.ListAutonomousDatabaseCharacterSetsResponse
        ],
        request: oracledatabase.ListAutonomousDatabaseCharacterSetsRequest,
        response: oracledatabase.ListAutonomousDatabaseCharacterSetsResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.oracledatabase_v1.types.ListAutonomousDatabaseCharacterSetsRequest):
                The initial request object.
            response (google.cloud.oracledatabase_v1.types.ListAutonomousDatabaseCharacterSetsResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = oracledatabase.ListAutonomousDatabaseCharacterSetsRequest(
            request
        )
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(
        self,
    ) -> Iterator[oracledatabase.ListAutonomousDatabaseCharacterSetsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(
        self,
    ) -> Iterator[autonomous_database_character_set.AutonomousDatabaseCharacterSet]:
        for page in self.pages:
            yield from page.autonomous_database_character_sets

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListAutonomousDatabaseBackupsPager:
    """A pager for iterating through ``list_autonomous_database_backups`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.oracledatabase_v1.types.ListAutonomousDatabaseBackupsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``autonomous_database_backups`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListAutonomousDatabaseBackups`` requests and continue to iterate
    through the ``autonomous_database_backups`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.oracledatabase_v1.types.ListAutonomousDatabaseBackupsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., oracledatabase.ListAutonomousDatabaseBackupsResponse],
        request: oracledatabase.ListAutonomousDatabaseBackupsRequest,
        response: oracledatabase.ListAutonomousDatabaseBackupsResponse,
        *,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.oracledatabase_v1.types.ListAutonomousDatabaseBackupsRequest):
                The initial request object.
            response (google.cloud.oracledatabase_v1.types.ListAutonomousDatabaseBackupsResponse):
                The initial response object.
            retry (google.api_core.retry.Retry): Designation of what errors,
                if any, should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = oracledatabase.ListAutonomousDatabaseBackupsRequest(request)
        self._response = response
        self._retry = retry
        self._timeout = timeout
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[oracledatabase.ListAutonomousDatabaseBackupsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(
                self._request,
                retry=self._retry,
                timeout=self._timeout,
                metadata=self._metadata,
            )
            yield self._response

    def __iter__(self) -> Iterator[autonomous_db_backup.AutonomousDatabaseBackup]:
        for page in self.pages:
            yield from page.autonomous_database_backups

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.oracledatabase.v1",
    manifest={
        "LocationMetadata",
    },
)


class LocationMetadata(proto.Message):
    r"""Metadata for a given [Location][google.cloud.location.Location].

    Attributes:
        gcp_oracle_zones (MutableSequence[str]):
            Output only. Google Cloud Platform Oracle
            zones in a location.
    """

    gcp_oracle_zones: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.oracledatabase.v1",
    manifest={
        "AutonomousDatabaseCharacterSet",
    },
)


class AutonomousDatabaseCharacterSet(proto.Message):
    r"""Details of the Autonomous Database character set resource.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/AutonomousDatabaseCharacterSets/

    Attributes:
        name (str):
            Identifier. The name of the Autonomous Database Character
            Set resource in the following format:
            projects/{project}/locations/{region}/autonomousDatabaseCharacterSets/{autonomous_database_character_set}
        character_set_type (google.cloud.oracledatabase_v1.types.AutonomousDatabaseCharacterSet.CharacterSetType):
            Output only. The character set type for the
            Autonomous Database.
        character_set (str):
            Output only. The character set name for the
            Autonomous Database which is the ID in the
            resource name.
    """

    class CharacterSetType(proto.Enum):
        r"""The type of character set an Autonomous Database can have.

        Values:
            CHARACTER_SET_TYPE_UNSPECIFIED (0):
                Character set type is not specified.
            DATABASE (1):
                Character set type is set to database.
            NATIONAL (2):
                Character set type is set to national.
        """
        CHARACTER_SET_TYPE_UNSPECIFIED = 0
        DATABASE = 1
        NATIONAL = 2

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    character_set_type: CharacterSetType = proto.Field(
        proto.ENUM,
        number=2,
        enum=CharacterSetType,
    )
    character_set: str = proto.Field(
        proto.STRING,
        number=3,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.oracledatabase.v1",
    manifest={
        "DbSystemShape",
    },
)


class DbSystemShape(proto.Message):
    r"""Details of the Database System Shapes resource.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/DbSystemShapeSummary/

    Attributes:
        name (str):
            Identifier. The name of the Database System Shape resource
            with the format:
            projects/{project}/locations/{region}/dbSystemShapes/{db_system_shape}
        shape (str):
            Optional. shape
        min_node_count (int):
            Optional. Minimum number of database servers.
        max_node_count (int):
            Optional. Maximum number of database servers.
        min_storage_count (int):
            Optional. Minimum number of storage servers.
        max_storage_count (int):
            Optional. Maximum number of storage servers.
        available_core_count_per_node (int):
            Optional. Number of cores per node.
        available_memory_per_node_gb (int):
            Optional. Memory per database server node in
            gigabytes.
        available_data_storage_tb (int):
            Optional. Storage per storage server in
            terabytes.
        min_core_count_per_node (int):
            Optional. Minimum core count per node.
        min_memory_per_node_gb (int):
            Optional. Minimum memory per node in
            gigabytes.
        min_db_node_storage_per_node_gb (int):
            Optional. Minimum node storage per database
            server in gigabytes.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    shape: str = proto.Field(
        proto.STRING,
        number=2,
    )
    min_node_count: int = proto.Field(
        proto.INT32,
        number=3,
    )
    max_node_count: int = proto.Field(
        proto.INT32,
        number=4,
    )
    min_storage_count: int = proto.Field(
        proto.INT32,
        number=5,
    )
    max_storage_count: int = proto.Field(
        proto.INT32,
        number=6,
    )
    available_core_count_per_node: int = proto.Field(
        proto.INT32,
        number=7,
    )
    available_memory_per_node_gb: int = proto.Field(
        proto.INT32,
        number=8,
    )
    available_data_storage_tb: int = proto.Field(
        proto.INT32,
        number=9,
    )
    min_core_count_per_node: int = proto.Field(
        proto.INT32,
        number=10,
    )
    min_memory_per_node_gb: int = proto.Field(
        proto.INT32,
        number=11,
    )
    min_db_node_storage_per_node_gb: int = proto.Field(
        proto.INT32,
        number=12,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.oracledatabase.v1",
    manifest={
        "DbNode",
        "DbNodeProperties",
    },
)


class DbNode(proto.Message):
    r"""Details of the database node resource.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/DbNode/

    Attributes:
        name (str):
            Identifier. The name of the database node resource in the
            following format:
            projects/{project}/locations/{location}/cloudVmClusters/{cloud_vm_cluster}/dbNodes/{db_node}
        properties (google.cloud.oracledatabase_v1.types.DbNodeProperties):
            Optional. Various properties of the database
            node.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    properties: "DbNodeProperties" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="DbNodeProperties",
    )


class DbNodeProperties(proto.Message):
    r"""Various properties and settings associated with Db node.

    Attributes:
        ocid (str):
            Output only. OCID of database node.
        ocpu_count (int):
            Optional. OCPU count per database node.
        memory_size_gb (int):
            Memory allocated in GBs.
        db_node_storage_size_gb (int):
            Optional. Local storage per database node.
        db_server_ocid (str):
            Optional. Database server OCID.
        hostname (str):
            Optional. DNS
        state (google.cloud.oracledatabase_v1.types.DbNodeProperties.State):
            Output only. State of the database node.
        total_cpu_core_count (int):
            Total CPU core count of the database node.
    """

    class State(proto.Enum):
        r"""The various lifecycle states of the database node.

        Values:
            STATE_UNSPECIFIED (0):
                Default unspecified value.
            PROVISIONING (1):
                Indicates that the resource is in
                provisioning state.
            AVAILABLE (2):
                Indicates that the resource is in available
                state.
            UPDATING (3):
                Indicates that the resource is in updating
                state.
            STOPPING (4):
                Indicates that the resource is in stopping
                state.
            STOPPED (5):
                Indicates that the resource is in stopped
                state.
            STARTING (6):
                Indicates that the resource is in starting
                state.
            TERMINATING (7):
                Indicates that the resource is in terminating
                state.
            TERMINATED (8):
                Indicates that the resource is in terminated
                state.
            FAILED (9):
                Indicates that the resource is in failed
                state.
        """
        STATE_UNSPECIFIED = 0
        PROVISIONING = 1
        AVAILABLE = 2
        UPDATING = 3
        STOPPING = 4
        STOPPED = 5
        STARTING = 6
        TERMINATING = 7
        TERMINATED = 8
        FAILED = 9

    ocid: str = proto.Field(
        proto.STRING,
        number=1,
    )
    ocpu_count: int = proto.Field(
        proto.INT32,
        number=2,
    )
    memory_size_gb: int = proto.Field(
        proto.INT32,
        number=3,
    )
    db_node_storage_size_gb: int = proto.Field(
        proto.INT32,
        number=4,
    )
    db_server_ocid: str = proto.Field(
        proto.STRING,
        number=5,
    )
    hostname: str = proto.Field(
        proto.STRING,
        number=8,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=9,
        enum=State,
    )
    total_cpu_core_count: int = proto.Field(
        proto.INT32,
        number=10,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.oracledatabase.v1",
    manifest={
        "DbServer",
        "DbServerProperties",
    },
)


class DbServer(proto.Message):
    r"""Details of the database server resource.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/DbServer/

    Attributes:
        name (str):
            Identifier. The name of the database server resource with
            the format:
            projects/{project}/locations/{location}/cloudExadataInfrastructures/{cloud_exadata_infrastructure}/dbServers/{db_server}
        display_name (str):
            Optional. User friendly name for this
            resource.
        properties (google.cloud.oracledatabase_v1.types.DbServerProperties):
            Optional. Various properties of the database
            server.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    properties: "DbServerProperties" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="DbServerProperties",
    )


class DbServerProperties(proto.Message):
    r"""Various properties and settings associated with Exadata
    database server.

    Attributes:
        ocid (str):
            Output only. OCID of database server.
        ocpu_count (int):
            Optional. OCPU count per database.
        max_ocpu_count (int):
            Optional. Maximum OCPU count per database.
        memory_size_gb (int):
            Optional. Memory allocated in GBs.
        max_memory_size_gb (int):
            Optional. Maximum memory allocated in GBs.
        db_node_storage_size_gb (int):
            Optional. Local storage per VM.
        max_db_node_storage_size_gb (int):
            Optional. Maximum local storage per VM.
        vm_count (int):
            Optional. Vm count per database.
        state (google.cloud.oracledatabase_v1.types.DbServerProperties.State):
            Output only. State of the database server.
        db_node_ids (MutableSequence[str]):
            Output only. OCID of database nodes
            associated with the database server.
    """

    class State(proto.Enum):
        r"""The various lifecycle states of the database server.

        Values:
            STATE_UNSPECIFIED (0):
                Default unspecified value.
            CREATING (1):
                Indicates that the resource is in creating
                state.
            AVAILABLE (2):
                Indicates that the resource is in available
                state.
            UNAVAILABLE (3):
                Indicates that the resource is in unavailable
                state.
            DELETING (4):
                Indicates that the resource is in deleting
                state.
            DELETED (5):
                Indicates that the resource is in deleted
                state.
        """
        STATE_UNSPECIFIED = 0
        CREATING = 1
        AVAILABLE = 2
        UNAVAILABLE = 3
        DELETING = 4
        DELETED = 5

    ocid: str = proto.Field(
        proto.STRING,
        number=1,
    )
    ocpu_count: int = proto.Field(
        proto.INT32,
        number=2,
    )
    max_ocpu_count: int = proto.Field(
        proto.INT32,
        number=3,
    )
    memory_size_gb: int = proto.Field(
        proto.INT32,
        number=4,
    )
    max_memory_size_gb: int = proto.Field(
        proto.INT32,
        number=5,
    )
    db_node_storage_size_gb: int = proto.Field(
        proto.INT32,
        number=6,
    )
    max_db_node_storage_size_gb: int = proto.Field(
        proto.INT32,
        number=7,
    )
    vm_count: int = proto.Field(
        proto.INT32,
        number=8,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=9,
        enum=State,
    )
    db_node_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=10,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.oracledatabase.v1",
    manifest={
        "Entitlement",
        "CloudAccountDetails",
    },
)


class Entitlement(proto.Message):
    r"""Details of the Entitlement resource.

    Attributes:
        name (str):
            Identifier. The name of the Entitlement
            resource with the format:
            projects/{project}/locations/{region}/entitlements/{entitlement}
        cloud_account_details (google.cloud.oracledatabase_v1.types.CloudAccountDetails):
            Details of the OCI Cloud Account.
        entitlement_id (str):
            Output only. Google Cloud Marketplace order
            ID (aka entitlement ID)
        state (google.cloud.oracledatabase_v1.types.Entitlement.State):
            Output only. Entitlement State.
    """

    class State(proto.Enum):
        r"""The various lifecycle states of the subscription.

        Values:
            STATE_UNSPECIFIED (0):
                Default unspecified value.
            ACCOUNT_NOT_LINKED (1):
                Account not linked.
            ACCOUNT_NOT_ACTIVE (2):
                Account is linked but not active.
            ACTIVE (3):
                Entitlement and Account are active.
        """
        STATE_UNSPECIFIED = 0
        ACCOUNT_NOT_LINKED = 1
        ACCOUNT_NOT_ACTIVE = 2
        ACTIVE = 3

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    cloud_account_details: "CloudAccountDetails" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="CloudAccountDetails",
    )
    entitlement_id: str = proto.Field(
        proto.STRING,
        number=3,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=4,
        enum=State,
    )


class CloudAccountDetails(proto.Message):
    r"""Details of the OCI Cloud Account.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        cloud_account (str):
            Output only. OCI account name.
        cloud_account_home_region (str):
            Output only. OCI account home region.
        link_existing_account_uri (str):
            Output only. URL to link an existing account.

            This field is a member of `oneof`_ ``_link_existing_account_uri``.
        account_creation_uri (str):
            Output only. URL to create a new account and
            link.

            This field is a member of `oneof`_ ``_account_creation_uri``.
    """

    cloud_account: str = proto.Field(
        proto.STRING,
        number=1,
    )
    cloud_account_home_region: str = proto.Field(
        proto.STRING,
        number=2,
    )
    link_existing_account_uri: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    account_creation_uri: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
from google.type import dayofweek_pb2  # type: ignore
from google.type import timeofday_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.oracledatabase_v1.types import common

__protobuf__ = proto.module(
    package="google.cloud.oracledatabase.v1",
    manifest={
        "GenerateType",
        "State",
        "OperationsInsightsState",
        "DBWorkload",
        "AutonomousDatabase",
        "AutonomousDatabaseProperties",
        "AutonomousDatabaseApex",
        "AutonomousDatabaseConnectionStrings",
        "DatabaseConnectionStringProfile",
        "AllConnectionStrings",
        "AutonomousDatabaseConnectionUrls",
        "AutonomousDatabaseStandbySummary",
        "ScheduledOperationDetails",
    },
)


class GenerateType(proto.Enum):
    r"""The type of wallet generation.

    Values:
        GENERATE_TYPE_UNSPECIFIED (0):
            Default unspecified value.
        ALL (1):
            Used to generate wallet for all databases in
            the region.
        SINGLE (2):
            Used to generate wallet for a single
            database.
    """
    GENERATE_TYPE_UNSPECIFIED = 0
    ALL = 1
    SINGLE = 2


class State(proto.Enum):
    r"""The various lifecycle states of the Autonomous Database.

    Values:
        STATE_UNSPECIFIED (0):
            Default unspecified value.
        PROVISIONING (1):
            Indicates that the Autonomous Database is in
            provisioning state.
        AVAILABLE (2):
            Indicates that the Autonomous Database is in
            available state.
        STOPPING (3):
            Indicates that the Autonomous Database is in
            stopping state.
        STOPPED (4):
            Indicates that the Autonomous Database is in
            stopped state.
        STARTING (5):
            Indicates that the Autonomous Database is in
            starting state.
        TERMINATING (6):
            Indicates that the Autonomous Database is in
            terminating state.
        TERMINATED (7):
            Indicates that the Autonomous Database is in
            terminated state.
        UNAVAILABLE (8):
            Indicates that the Autonomous Database is in
            unavailable state.
        RESTORE_IN_PROGRESS (9):
            Indicates that the Autonomous Database
            restore is in progress.
        RESTORE_FAILED (10):
            Indicates that the Autonomous Database failed
            to restore.
        BACKUP_IN_PROGRESS (11):
            Indicates that the Autonomous Database backup
            is in progress.
        SCALE_IN_PROGRESS (12):
            Indicates that the Autonomous Database scale
            is in progress.
        AVAILABLE_NEEDS_ATTENTION (13):
            Indicates that the Autonomous Database is
            available but needs attention state.
        UPDATING (14):
            Indicates that the Autonomous Database is in
            updating state.
        MAINTENANCE_IN_PROGRESS (15):
            Indicates that the Autonomous Database's
            maintenance is in progress state.
        RESTARTING (16):
            Indicates that the Autonomous Database is in
            restarting state.
        RECREATING (17):
            Indicates that the Autonomous Database is in
            recreating state.
        ROLE_CHANGE_IN_PROGRESS (18):
            Indicates that the Autonomous Database's role
            change is in progress state.
        UPGRADING (19):
            Indicates that the Autonomous Database is in
            upgrading state.
        INACCESSIBLE (20):
            Indicates that the Autonomous Database is in
            inaccessible state.
        STANDBY (21):
            Indicates that the Autonomous Database is in
            standby state.
    """
    STATE_UNSPECIFIED = 0
    PROVISIONING = 1
    AVAILABLE = 2
    STOPPING = 3
    STOPPED = 4
    STARTING = 5
    TERMINATING = 6
    TERMINATED = 7
    UNAVAILABLE = 8
    RESTORE_IN_PROGRESS = 9
    RESTORE_FAILED = 10
    BACKUP_IN_PROGRESS = 11
    SCALE_IN_PROGRESS = 12
    AVAILABLE_NEEDS_ATTENTION = 13
    UPDATING = 14
    MAINTENANCE_IN_PROGRESS = 15
    RESTARTING = 16
    RECREATING = 17
    ROLE_CHANGE_IN_PROGRESS = 18
    UPGRADING = 19
    INACCESSIBLE = 20
    STANDBY = 21


class OperationsInsightsState(proto.Enum):
    r"""The state of the Operations Insights for this Autonomous
    Database.

    Values:
        OPERATIONS_INSIGHTS_STATE_UNSPECIFIED (0):
            Default unspecified value.
        ENABLING (1):
            Enabling status for operation insights.
        ENABLED (2):
            Enabled status for operation insights.
        DISABLING (3):
            Disabling status for operation insights.
        NOT_ENABLED (4):
            Not Enabled status for operation insights.
        FAILED_ENABLING (5):
            Failed enabling status for operation
            insights.
        FAILED_DISABLING (6):
            Failed disabling status for operation
            insights.
    """
    OPERATIONS_INSIGHTS_STATE_UNSPECIFIED = 0
    ENABLING = 1
    ENABLED = 2
    DISABLING = 3
    NOT_ENABLED = 4
    FAILED_ENABLING = 5
    FAILED_DISABLING = 6


class DBWorkload(proto.Enum):
    r"""The various states available for the Autonomous Database
    workload type.

    Values:
        DB_WORKLOAD_UNSPECIFIED (0):
            Default unspecified value.
        OLTP (1):
            Autonomous Transaction Processing database.
        DW (2):
            Autonomous Data Warehouse database.
        AJD (3):
            Autonomous JSON Database.
        APEX (4):
            Autonomous Database with the Oracle APEX
            Application Development workload type.
    """
    DB_WORKLOAD_UNSPECIFIED = 0
    OLTP = 1
    DW = 2
    AJD = 3
    APEX = 4


class AutonomousDatabase(proto.Message):
    r"""Details of the Autonomous Database resource.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/AutonomousDatabase/

    Attributes:
        name (str):
            Identifier. The name of the Autonomous Database resource in
            the following format:
            projects/{project}/locations/{region}/autonomousDatabases/{autonomous_database}
        database (str):
            Optional. The name of the Autonomous
            Database. The database name must be unique in
            the project. The name must begin with a letter
            and can contain a maximum of 30 alphanumeric
            characters.
        display_name (str):
            Optional. The display name for the Autonomous
            Database. The name does not have to be unique
            within your project.
        entitlement_id (str):
            Output only. The ID of the subscription
            entitlement associated with the Autonomous
            Database.
        admin_password (str):
            Optional. The password for the default ADMIN
            user.
        properties (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties):
            Optional. The properties of the Autonomous
            Database.
        labels (MutableMapping[str, str]):
            Optional. The labels or tags associated with
            the Autonomous Database.
        network (str):
            Required. The name of the VPC network used by
            the Autonomous Database in the following format:
            projects/{project}/global/networks/{network}
        cidr (str):
            Required. The subnet CIDR range for the
            Autonmous Database.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The date and time that the
            Autonomous Database was created.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    database: str = proto.Field(
        proto.STRING,
        number=2,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
    )
    entitlement_id: str = proto.Field(
        proto.STRING,
        number=5,
    )
    admin_password: str = proto.Field(
        proto.STRING,
        number=6,
    )
    properties: "AutonomousDatabaseProperties" = proto.Field(
        proto.MESSAGE,
        number=7,
        message="AutonomousDatabaseProperties",
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=8,
    )
    network: str = proto.Field(
        proto.STRING,
        number=9,
    )
    cidr: str = proto.Field(
        proto.STRING,
        number=10,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=13,
        message=timestamp_pb2.Timestamp,
    )


class AutonomousDatabaseProperties(proto.Message):
    r"""The properties of an Autonomous Database.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        ocid (str):
            Output only. OCID of the Autonomous Database.
            https://docs.oracle.com/en-us/iaas/Content/General/Concepts/identifiers.htm#Oracle
        compute_count (float):
            Optional. The number of compute servers for
            the Autonomous Database.
        cpu_core_count (int):
            Optional. The number of CPU cores to be made
            available to the database.
        data_storage_size_tb (int):
            Optional. The size of the data stored in the
            database, in terabytes.
        data_storage_size_gb (int):
            Optional. The size of the data stored in the
            database, in gigabytes.
        db_workload (google.cloud.oracledatabase_v1.types.DBWorkload):
            Required. The workload type of the Autonomous
            Database.
        db_edition (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties.DatabaseEdition):
            Optional. The edition of the Autonomous
            Databases.
        character_set (str):
            Optional. The character set for the
            Autonomous Database. The default is AL32UTF8.
        n_character_set (str):
            Optional. The national character set for the
            Autonomous Database. The default is AL16UTF16.
        private_endpoint_ip (str):
            Optional. The private endpoint IP address for
            the Autonomous Database.
        private_endpoint_label (str):
            Optional. The private endpoint label for the
            Autonomous Database.
        db_version (str):
            Optional. The Oracle Database version for the
            Autonomous Database.
        is_auto_scaling_enabled (bool):
            Optional. This field indicates if auto
            scaling is enabled for the Autonomous Database
            CPU core count.
        is_storage_auto_scaling_enabled (bool):
            Optional. This field indicates if auto
            scaling is enabled for the Autonomous Database
            storage.
        license_type (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties.LicenseType):
            Required. The license type used for the
            Autonomous Database.
        customer_contacts (MutableSequence[google.cloud.oracledatabase_v1.types.CustomerContact]):
            Optional. The list of customer contacts.
        secret_id (str):
            Optional. The ID of the Oracle Cloud
            Infrastructure vault secret.
        vault_id (str):
            Optional. The ID of the Oracle Cloud
            Infrastructure vault.
        maintenance_schedule_type (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties.MaintenanceScheduleType):
            Optional. The maintenance schedule of the
            Autonomous Database.
        mtls_connection_required (bool):
            Optional. This field specifies if the
            Autonomous Database requires mTLS connections.
        backup_retention_period_days (int):
            Optional. The retention period for the
            Autonomous Database. This field is specified in
            days, can range from 1 day to 60 days, and has a
            default value of 60 days.
        actual_used_data_storage_size_tb (float):
            Output only. The amount of storage currently
            being used for user and system data, in
            terabytes.
        allocated_storage_size_tb (float):
            Output only. The amount of storage currently
            allocated for the database tables and billed
            for, rounded up in terabytes.
        apex_details (google.cloud.oracledatabase_v1.types.AutonomousDatabaseApex):
            Output only. The details for the Oracle APEX
            Application Development.
        are_primary_allowlisted_ips_used (bool):
            Output only. This field indicates the status
            of Data Guard and Access control for the
            Autonomous Database. The field's value is null
            if Data Guard is disabled or Access Control is
            disabled. The field's value is TRUE if both Data
            Guard and Access Control are enabled, and the
            Autonomous Database is using primary IP access
            control list (ACL) for standby. The field's
            value is FALSE if both Data Guard and Access
            Control are enabled, and the Autonomous Database
            is using a different IP access control list
            (ACL) for standby compared to primary.

            This field is a member of `oneof`_ ``_are_primary_allowlisted_ips_used``.
        lifecycle_details (str):
            Output only. The details of the current
            lifestyle state of the Autonomous Database.
        state (google.cloud.oracledatabase_v1.types.State):
            Output only. The current lifecycle state of
            the Autonomous Database.
        autonomous_container_database_id (str):
            Output only. The Autonomous Container
            Database OCID.
        available_upgrade_versions (MutableSequence[str]):
            Output only. The list of available Oracle
            Database upgrade versions for an Autonomous
            Database.
        connection_strings (google.cloud.oracledatabase_v1.types.AutonomousDatabaseConnectionStrings):
            Output only. The connection strings used to
            connect to an Autonomous Database.
        connection_urls (google.cloud.oracledatabase_v1.types.AutonomousDatabaseConnectionUrls):
            Output only. The Oracle Connection URLs for
            an Autonomous Database.
        failed_data_recovery_duration (google.protobuf.duration_pb2.Duration):
            Output only. This field indicates the number
            of seconds of data loss during a Data Guard
            failover.
        memory_table_gbs (int):
            Output only. The memory assigned to in-memory
            tables in an Autonomous Database.
        is_local_data_guard_enabled (bool):
            Output only. This field indicates whether the
            Autonomous Database has local (in-region) Data
            Guard enabled.
        local_adg_auto_failover_max_data_loss_limit (int):
            Output only. This field indicates the maximum
            data loss limit for an Autonomous Database, in
            seconds.
        local_standby_db (google.cloud.oracledatabase_v1.types.AutonomousDatabaseStandbySummary):
            Output only. The details of the Autonomous
            Data Guard standby database.
        memory_per_oracle_compute_unit_gbs (int):
            Output only. The amount of memory enabled per
            ECPU, in gigabytes.
        local_disaster_recovery_type (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties.LocalDisasterRecoveryType):
            Output only. This field indicates the local
            disaster recovery (DR) type of an Autonomous
            Database.
        data_safe_state (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties.DataSafeState):
            Output only. The current state of the Data
            Safe registration for the Autonomous Database.
        database_management_state (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties.DatabaseManagementState):
            Output only. The current state of database
            management for the Autonomous Database.
        open_mode (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties.OpenMode):
            Output only. This field indicates the current
            mode of the Autonomous Database.
        operations_insights_state (google.cloud.oracledatabase_v1.types.OperationsInsightsState):
            Output only. This field indicates the state
            of Operations Insights for the Autonomous
            Database.
        peer_db_ids (MutableSequence[str]):
            Output only. The list of OCIDs of standby
            databases located in Autonomous Data Guard
            remote regions that are associated with the
            source database.
        permission_level (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties.PermissionLevel):
            Output only. The permission level of the
            Autonomous Database.
        private_endpoint (str):
            Output only. The private endpoint for the
            Autonomous Database.
        refreshable_mode (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties.RefreshableMode):
            Output only. The refresh mode of the cloned
            Autonomous Database.
        refreshable_state (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties.RefreshableState):
            Output only. The refresh State of the clone.
        role (google.cloud.oracledatabase_v1.types.AutonomousDatabaseProperties.Role):
            Output only. The Data Guard role of the
            Autonomous Database.
        scheduled_operation_details (MutableSequence[google.cloud.oracledatabase_v1.types.ScheduledOperationDetails]):
            Output only. The list and details of the
            scheduled operations of the Autonomous Database.
        sql_web_developer_url (str):
            Output only. The SQL Web Developer URL for
            the Autonomous Database.
        supported_clone_regions (MutableSequence[str]):
            Output only. The list of available regions
            that can be used to create a clone for the
            Autonomous Database.
        used_data_storage_size_tbs (int):
            Output only. The storage space used by
            Autonomous Database, in gigabytes.
        oci_url (str):
            Output only. The Oracle Cloud Infrastructure
            link for the Autonomous Database.
        total_auto_backup_storage_size_gbs (float):
            Output only. The storage space used by
            automatic backups of Autonomous Database, in
            gigabytes.
        next_long_term_backup_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The long term backup schedule of
            the Autonomous Database.
        maintenance_begin_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The date and time when
            maintenance will begin.
        maintenance_end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The date and time when
            maintenance will end.
    """

    class DatabaseEdition(proto.Enum):
        r"""The editions available for the Autonomous Database.

        Values:
            DATABASE_EDITION_UNSPECIFIED (0):
                Default unspecified value.
            STANDARD_EDITION (1):
                Standard Database Edition
            ENTERPRISE_EDITION (2):
                Enterprise Database Edition
        """
        DATABASE_EDITION_UNSPECIFIED = 0
        STANDARD_EDITION = 1
        ENTERPRISE_EDITION = 2

    class LicenseType(proto.Enum):
        r"""The license types available for the Autonomous Database.

        Values:
            LICENSE_TYPE_UNSPECIFIED (0):
                Unspecified
            LICENSE_INCLUDED (1):
                License included part of offer
            BRING_YOUR_OWN_LICENSE (2):
                Bring your own license
        """
        LICENSE_TYPE_UNSPECIFIED = 0
        LICENSE_INCLUDED = 1
        BRING_YOUR_OWN_LICENSE = 2

    class MaintenanceScheduleType(proto.Enum):
        r"""The available maintenance schedules for the Autonomous
        Database.

        Values:
            MAINTENANCE_SCHEDULE_TYPE_UNSPECIFIED (0):
                Default unspecified value.
            EARLY (1):
                An EARLY maintenance schedule patches the
                database before the regular scheduled
                maintenance.
            REGULAR (2):
                A REGULAR maintenance schedule follows the
                normal maintenance cycle.
        """
        MAINTENANCE_SCHEDULE_TYPE_UNSPECIFIED = 0
        EARLY = 1
        REGULAR = 2

    class LocalDisasterRecoveryType(proto.Enum):
        r"""The types of local disaster recovery available for an
        Autonomous Database.

        Values:
            LOCAL_DISASTER_RECOVERY_TYPE_UNSPECIFIED (0):
                Default unspecified value.
            ADG (1):
                Autonomous Data Guard recovery.
            BACKUP_BASED (2):
                Backup based recovery.
        """
        LOCAL_DISASTER_RECOVERY_TYPE_UNSPECIFIED = 0
        ADG = 1
        BACKUP_BASED = 2

    class DataSafeState(proto.Enum):
        r"""Varies states of the Data Safe registration for the
        Autonomous Database.

        Values:
            DATA_SAFE_STATE_UNSPECIFIED (0):
                Default unspecified value.
            REGISTERING (1):
                Registering data safe state.
            REGISTERED (2):
                Registered data safe state.
            DEREGISTERING (3):
                Deregistering data safe state.
            NOT_REGISTERED (4):
                Not registered data safe state.
            FAILED (5):
                Failed data safe state.
        """
        DATA_SAFE_STATE_UNSPECIFIED = 0
        REGISTERING = 1
        REGISTERED = 2
        DEREGISTERING = 3
        NOT_REGISTERED = 4
        FAILED = 5

    class DatabaseManagementState(proto.Enum):
        r"""The different states of database management for an Autonomous
        Database.

        Values:
            DATABASE_MANAGEMENT_STATE_UNSPECIFIED (0):
                Default unspecified value.
            ENABLING (1):
                Enabling Database Management state
            ENABLED (2):
                Enabled Database Management state
            DISABLING (3):
                Disabling Database Management state
            NOT_ENABLED (4):
                Not Enabled Database Management state
            FAILED_ENABLING (5):
                Failed enabling Database Management state
            FAILED_DISABLING (6):
                Failed disabling Database Management state
        """
        DATABASE_MANAGEMENT_STATE_UNSPECIFIED = 0
        ENABLING = 1
        ENABLED = 2
        DISABLING = 3
        NOT_ENABLED = 4
        FAILED_ENABLING = 5
        FAILED_DISABLING = 6

    class OpenMode(proto.Enum):
        r"""This field indicates the modes of an Autonomous Database.

        Values:
            OPEN_MODE_UNSPECIFIED (0):
                Default unspecified value.
            READ_ONLY (1):
                Read Only Mode
            READ_WRITE (2):
                Read Write Mode
        """
        OPEN_MODE_UNSPECIFIED = 0
        READ_ONLY = 1
        READ_WRITE = 2

    class PermissionLevel(proto.Enum):
        r"""The types of permission levels for an Autonomous Database.

        Values:
            PERMISSION_LEVEL_UNSPECIFIED (0):
                Default unspecified value.
            RESTRICTED (1):
                Restricted mode allows access only by admin
                users.
            UNRESTRICTED (2):
                Normal access.
        """
        PERMISSION_LEVEL_UNSPECIFIED = 0
        RESTRICTED = 1
        UNRESTRICTED = 2

    class RefreshableMode(proto.Enum):
        r"""The refresh mode of the cloned Autonomous Database.

        Values:
            REFRESHABLE_MODE_UNSPECIFIED (0):
                The default unspecified value.
            AUTOMATIC (1):
                AUTOMATIC indicates that the cloned database
                is automatically refreshed with data from the
                source Autonomous Database.
            MANUAL (2):
                MANUAL indicates that the cloned database is
                manually refreshed with data from the source
                Autonomous Database.
        """
        REFRESHABLE_MODE_UNSPECIFIED = 0
        AUTOMATIC = 1
        MANUAL = 2

    class RefreshableState(proto.Enum):
        r"""The refresh state of the cloned Autonomous Database.

        Values:
            REFRESHABLE_STATE_UNSPECIFIED (0):
                Default unspecified value.
            REFRESHING (1):
                Refreshing
            NOT_REFRESHING (2):
                Not refreshed
        """
        REFRESHABLE_STATE_UNSPECIFIED = 0
        REFRESHING = 1
        NOT_REFRESHING = 2

    class Role(proto.Enum):
        r"""The Data Guard role of the Autonomous Database.

        Values:
            ROLE_UNSPECIFIED (0):
                Default unspecified value.
            PRIMARY (1):
                Primary role
            STANDBY (2):
                Standby role
            DISABLED_STANDBY (3):
                Disabled standby role
            BACKUP_COPY (4):
                Backup copy role
            SNAPSHOT_STANDBY (5):
                Snapshot standby role
        """
        ROLE_UNSPECIFIED = 0
        PRIMARY = 1
        STANDBY = 2
        DISABLED_STANDBY = 3
        BACKUP_COPY = 4
        SNAPSHOT_STANDBY = 5

    ocid: str = proto.Field(
        proto.STRING,
        number=1,
    )
    compute_count: float = proto.Field(
        proto.FLOAT,
        number=2,
    )
    cpu_core_count: int = proto.Field(
        proto.INT32,
        number=3,
    )
    data_storage_size_tb: int = proto.Field(
        proto.INT32,
        number=4,
    )
    data_storage_size_gb: int = proto.Field(
        proto.INT32,
        number=63,
    )
    db_workload: "DBWorkload" = proto.Field(
        proto.ENUM,
        number=5,
        enum="DBWorkload",
    )
    db_edition: DatabaseEdition = proto.Field(
        proto.ENUM,
        number=6,
        enum=DatabaseEdition,
    )
    character_set: str = proto.Field(
        proto.STRING,
        number=8,
    )
    n_character_set: str = proto.Field(
        proto.STRING,
        number=9,
    )
    private_endpoint_ip: str = proto.Field(
        proto.STRING,
        number=10,
    )
    private_endpoint_label: str = proto.Field(
        proto.STRING,
        number=11,
    )
    db_version: str = proto.Field(
        proto.STRING,
        number=12,
    )
    is_auto_scaling_enabled: bool = proto.Field(
        proto.BOOL,
        number=14,
    )
    is_storage_auto_scaling_enabled: bool = proto.Field(
        proto.BOOL,
        number=15,
    )
    license_type: LicenseType = proto.Field(
        proto.ENUM,
        number=16,
        enum=LicenseType,
    )
    customer_contacts: MutableSequence[common.CustomerContact] = proto.RepeatedField(
        proto.MESSAGE,
        number=17,
        message=common.CustomerContact,
    )
    secret_id: str = proto.Field(
        proto.STRING,
        number=18,
    )
    vault_id: str = proto.Field(
        proto.STRING,
        number=19,
    )
    maintenance_schedule_type: MaintenanceScheduleType = proto.Field(
        proto.ENUM,
        number=20,
        enum=MaintenanceScheduleType,
    )
    mtls_connection_required: bool = proto.Field(
        proto.BOOL,
        number=34,
    )
    backup_retention_period_days: int = proto.Field(
        proto.INT32,
        number=57,
    )
    actual_used_data_storage_size_tb: float = proto.Field(
        proto.DOUBLE,
        number=21,
    )
    allocated_storage_size_tb: float = proto.Field(
        proto.DOUBLE,
        number=22,
    )
    apex_details: "AutonomousDatabaseApex" = proto.Field(
        proto.MESSAGE,
        number=23,
        message="AutonomousDatabaseApex",
    )
    are_primary_allowlisted_ips_used: bool = proto.Field(
        proto.BOOL,
        number=24,
        optional=True,
    )
    lifecycle_details: str = proto.Field(
        proto.STRING,
        number=25,
    )
    state: "State" = proto.Field(
        proto.ENUM,
        number=26,
        enum="State",
    )
    autonomous_container_database_id: str = proto.Field(
        proto.STRING,
        number=27,
    )
    available_upgrade_versions: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=28,
    )
    connection_strings: "AutonomousDatabaseConnectionStrings" = proto.Field(
        proto.MESSAGE,
        number=29,
        message="AutonomousDatabaseConnectionStrings",
    )
    connection_urls: "AutonomousDatabaseConnectionUrls" = proto.Field(
        proto.MESSAGE,
        number=30,
        message="AutonomousDatabaseConnectionUrls",
    )
    failed_data_recovery_duration: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=31,
        message=duration_pb2.Duration,
    )
    memory_table_gbs: int = proto.Field(
        proto.INT32,
        number=32,
    )
    is_local_data_guard_enabled: bool = proto.Field(
        proto.BOOL,
        number=33,
    )
    local_adg_auto_failover_max_data_loss_limit: int = proto.Field(
        proto.INT32,
        number=35,
    )
    local_standby_db: "AutonomousDatabaseStandbySummary" = proto.Field(
        proto.MESSAGE,
        number=36,
        message="AutonomousDatabaseStandbySummary",
    )
    memory_per_oracle_compute_unit_gbs: int = proto.Field(
        proto.INT32,
        number=37,
    )
    local_disaster_recovery_type: LocalDisasterRecoveryType = proto.Field(
        proto.ENUM,
        number=38,
        enum=LocalDisasterRecoveryType,
    )
    data_safe_state: DataSafeState = proto.Field(
        proto.ENUM,
        number=39,
        enum=DataSafeState,
    )
    database_management_state: DatabaseManagementState = proto.Field(
        proto.ENUM,
        number=40,
        enum=DatabaseManagementState,
    )
    open_mode: OpenMode = proto.Field(
        proto.ENUM,
        number=41,
        enum=OpenMode,
    )
    operations_insights_state: "OperationsInsightsState" = proto.Field(
        proto.ENUM,
        number=42,
        enum="OperationsInsightsState",
    )
    peer_db_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=43,
    )
    permission_level: PermissionLevel = proto.Field(
        proto.ENUM,
        number=44,
        enum=PermissionLevel,
    )
    private_endpoint: str = proto.Field(
        proto.STRING,
        number=45,
    )
    refreshable_mode: RefreshableMode = proto.Field(
        proto.ENUM,
        number=46,
        enum=RefreshableMode,
    )
    refreshable_state: RefreshableState = proto.Field(
        proto.ENUM,
        number=47,
        enum=RefreshableState,
    )
    role: Role = proto.Field(
        proto.ENUM,
        number=48,
        enum=Role,
    )
    scheduled_operation_details: MutableSequence[
        "ScheduledOperationDetails"
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=64,
        message="ScheduledOperationDetails",
    )
    sql_web_developer_url: str = proto.Field(
        proto.STRING,
        number=50,
    )
    supported_clone_regions: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=51,
    )
    used_data_storage_size_tbs: int = proto.Field(
        proto.INT32,
        number=53,
    )
    oci_url: str = proto.Field(
        proto.STRING,
        number=54,
    )
    total_auto_backup_storage_size_gbs: float = proto.Field(
        proto.FLOAT,
        number=59,
    )
    next_long_term_backup_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=60,
        message=timestamp_pb2.Timestamp,
    )
    maintenance_begin_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=65,
        message=timestamp_pb2.Timestamp,
    )
    maintenance_end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=66,
        message=timestamp_pb2.Timestamp,
    )


class AutonomousDatabaseApex(proto.Message):
    r"""Oracle APEX Application Development.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/AutonomousDatabaseApex

    Attributes:
        apex_version (str):
            Output only. The Oracle APEX Application
            Development version.
        ords_version (str):
            Output only. The Oracle REST Data Services
            (ORDS) version.
    """

    apex_version: str = proto.Field(
        proto.STRING,
        number=1,
    )
    ords_version: str = proto.Field(
        proto.STRING,
        number=2,
    )


class AutonomousDatabaseConnectionStrings(proto.Message):
    r"""The connection string used to connect to the Autonomous
    Database.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/AutonomousDatabaseConnectionStrings

    Attributes:
        all_connection_strings (google.cloud.oracledatabase_v1.types.AllConnectionStrings):
            Output only. Returns all connection strings
            that can be used to connect to the Autonomous
            Database.
        dedicated (str):
            Output only. The database service provides
            the least level of resources to each SQL
            statement, but supports the most number of
            concurrent SQL statements.
        high (str):
            Output only. The database service provides
            the highest level of resources to each SQL
            statement.
        low (str):
            Output only. The database service provides
            the least level of resources to each SQL
            statement.
        medium (str):
            Output only. The database service provides a
            lower level of resources to each SQL statement.
        profiles (MutableSequence[google.cloud.oracledatabase_v1.types.DatabaseConnectionStringProfile]):
            Output only. A list of connection string
            profiles to allow clients to group, filter, and
            select values based on the structured metadata.
    """

    all_connection_strings: "AllConnectionStrings" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="AllConnectionStrings",
    )
    dedicated: str = proto.Field(
        proto.STRING,
        number=2,
    )
    high: str = proto.Field(
        proto.STRING,
        number=3,
    )
    low: str = proto.Field(
        proto.STRING,
        number=4,
    )
    medium: str = proto.Field(
        proto.STRING,
        number=5,
    )
    profiles: MutableSequence["DatabaseConnectionStringProfile"] = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message="DatabaseConnectionStringProfile",
    )


class DatabaseConnectionStringProfile(proto.Message):
    r"""The connection string profile to allow clients to group.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/DatabaseConnectionStringProfile

    Attributes:
        consumer_group (google.cloud.oracledatabase_v1.types.DatabaseConnectionStringProfile.ConsumerGroup):
            Output only. The current consumer group being
            used by the connection.
        display_name (str):
            Output only. The display name for the
            database connection.
        host_format (google.cloud.oracledatabase_v1.types.DatabaseConnectionStringProfile.HostFormat):
            Output only. The host name format being
            currently used in connection string.
        is_regional (bool):
            Output only. This field indicates if the
            connection string is regional and is only
            applicable for cross-region Data Guard.
        protocol (google.cloud.oracledatabase_v1.types.DatabaseConnectionStringProfile.Protocol):
            Output only. The protocol being used by the
            connection.
        session_mode (google.cloud.oracledatabase_v1.types.DatabaseConnectionStringProfile.SessionMode):
            Output only. The current session mode of the
            connection.
        syntax_format (google.cloud.oracledatabase_v1.types.DatabaseConnectionStringProfile.SyntaxFormat):
            Output only. The syntax of the connection
            string.
        tls_authentication (google.cloud.oracledatabase_v1.types.DatabaseConnectionStringProfile.TLSAuthentication):
            Output only. This field indicates the TLS
            authentication type of the connection.
        value (str):
            Output only. The value of the connection
            string.
    """

    class ConsumerGroup(proto.Enum):
        r"""The various consumer groups available in the connection
        string profile.

        Values:
            CONSUMER_GROUP_UNSPECIFIED (0):
                Default unspecified value.
            HIGH (1):
                High consumer group.
            MEDIUM (2):
                Medium consumer group.
            LOW (3):
                Low consumer group.
            TP (4):
                TP consumer group.
            TPURGENT (5):
                TPURGENT consumer group.
        """
        CONSUMER_GROUP_UNSPECIFIED = 0
        HIGH = 1
        MEDIUM = 2
        LOW = 3
        TP = 4
        TPURGENT = 5

    class HostFormat(proto.Enum):
        r"""The host name format being used in the connection string.

        Values:
            HOST_FORMAT_UNSPECIFIED (0):
                Default unspecified value.
            FQDN (1):
                FQDN
            IP (2):
                IP
        """
        HOST_FORMAT_UNSPECIFIED = 0
        FQDN = 1
        IP = 2

    class Protocol(proto.Enum):
        r"""The protocol being used by the connection.

        Values:
            PROTOCOL_UNSPECIFIED (0):
                Default unspecified value.
            TCP (1):
                Tcp
            TCPS (2):
                Tcps
        """
        PROTOCOL_UNSPECIFIED = 0
        TCP = 1
        TCPS = 2

    class SessionMode(proto.Enum):
        r"""The session mode of the connection.

        Values:
            SESSION_MODE_UNSPECIFIED (0):
                Default unspecified value.
            DIRECT (1):
                Direct
            INDIRECT (2):
                Indirect
        """
        SESSION_MODE_UNSPECIFIED = 0
        DIRECT = 1
        INDIRECT = 2

    class SyntaxFormat(proto.Enum):
        r"""Specifies syntax of the connection string.

        Values:
            SYNTAX_FORMAT_UNSPECIFIED (0):
                Default unspecified value.
            LONG (1):
                Long
            EZCONNECT (2):
                Ezconnect
            EZCONNECTPLUS (3):
                Ezconnectplus
        """
        SYNTAX_FORMAT_UNSPECIFIED = 0
        LONG = 1
        EZCONNECT = 2
        EZCONNECTPLUS = 3

    class TLSAuthentication(proto.Enum):
        r"""This field indicates the TLS authentication type of the
        connection.

        Values:
            TLS_AUTHENTICATION_UNSPECIFIED (0):
                Default unspecified value.
            SERVER (1):
                Server
            MUTUAL (2):
                Mutual
        """
        TLS_AUTHENTICATION_UNSPECIFIED = 0
        SERVER = 1
        MUTUAL = 2

    consumer_group: ConsumerGroup = proto.Field(
        proto.ENUM,
        number=1,
        enum=ConsumerGroup,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    host_format: HostFormat = proto.Field(
        proto.ENUM,
        number=3,
        enum=HostFormat,
    )
    is_regional: bool = proto.Field(
        proto.BOOL,
        number=4,
    )
    protocol: Protocol = proto.Field(
        proto.ENUM,
        number=5,
        enum=Protocol,
    )
    session_mode: SessionMode = proto.Field(
        proto.ENUM,
        number=6,
        enum=SessionMode,
    )
    syntax_format: SyntaxFormat = proto.Field(
        proto.ENUM,
        number=7,
        enum=SyntaxFormat,
    )
    tls_authentication: TLSAuthentication = proto.Field(
        proto.ENUM,
        number=8,
        enum=TLSAuthentication,
    )
    value: str = proto.Field(
        proto.STRING,
        number=9,
    )


class AllConnectionStrings(proto.Message):
    r"""A list of all connection strings that can be used to connect
    to the Autonomous Database.

    Attributes:
        high (str):
            Output only. The database service provides
            the highest level of resources to each SQL
            statement.
        low (str):
            Output only. The database service provides
            the least level of resources to each SQL
            statement.
        medium (str):
            Output only. The database service provides a
            lower level of resources to each SQL statement.
    """

    high: str = proto.Field(
        proto.STRING,
        number=1,
    )
    low: str = proto.Field(
        proto.STRING,
        number=2,
    )
    medium: str = proto.Field(
        proto.STRING,
        number=3,
    )


class AutonomousDatabaseConnectionUrls(proto.Message):
    r"""The URLs for accessing Oracle Application Express (APEX) and
    SQL Developer Web with a browser from a Compute instance.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/AutonomousDatabaseConnectionUrls

    Attributes:
        apex_uri (str):
            Output only. Oracle Application Express
            (APEX) URL.
        database_transforms_uri (str):
            Output only. The URL of the Database
            Transforms for the Autonomous Database.
        graph_studio_uri (str):
            Output only. The URL of the Graph Studio for
            the Autonomous Database.
        machine_learning_notebook_uri (str):
            Output only. The URL of the Oracle Machine
            Learning (OML) Notebook for the Autonomous
            Database.
        machine_learning_user_management_uri (str):
            Output only. The URL of Machine Learning user
            management the Autonomous Database.
        mongo_db_uri (str):
            Output only. The URL of the MongoDB API for
            the Autonomous Database.
        ords_uri (str):
            Output only. The Oracle REST Data Services
            (ORDS) URL of the Web Access for the Autonomous
            Database.
        sql_dev_web_uri (str):
            Output only. The URL of the Oracle SQL
            Developer Web for the Autonomous Database.
    """

    apex_uri: str = proto.Field(
        proto.STRING,
        number=1,
    )
    database_transforms_uri: str = proto.Field(
        proto.STRING,
        number=2,
    )
    graph_studio_uri: str = proto.Field(
        proto.STRING,
        number=3,
    )
    machine_learning_notebook_uri: str = proto.Field(
        proto.STRING,
        number=4,
    )
    machine_learning_user_management_uri: str = proto.Field(
        proto.STRING,
        number=5,
    )
    mongo_db_uri: str = proto.Field(
        proto.STRING,
        number=6,
    )
    ords_uri: str = proto.Field(
        proto.STRING,
        number=7,
    )
    sql_dev_web_uri: str = proto.Field(
        proto.STRING,
        number=8,
    )


class AutonomousDatabaseStandbySummary(proto.Message):
    r"""Autonomous Data Guard standby database details.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/AutonomousDatabaseStandbySummary

    Attributes:
        lag_time_duration (google.protobuf.duration_pb2.Duration):
            Output only. The amount of time, in seconds,
            that the data of the standby database lags in
            comparison to the data of the primary database.
        lifecycle_details (str):
            Output only. The additional details about the
            current lifecycle state of the Autonomous
            Database.
        state (google.cloud.oracledatabase_v1.types.State):
            Output only. The current lifecycle state of
            the Autonomous Database.
        data_guard_role_changed_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The date and time the Autonomous
            Data Guard role was switched for the standby
            Autonomous Database.
        disaster_recovery_role_changed_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The date and time the Disaster
            Recovery role was switched for the standby
            Autonomous Database.
    """

    lag_time_duration: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=1,
        message=duration_pb2.Duration,
    )
    lifecycle_details: str = proto.Field(
        proto.STRING,
        number=2,
    )
    state: "State" = proto.Field(
        proto.ENUM,
        number=3,
        enum="State",
    )
    data_guard_role_changed_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )
    disaster_recovery_role_changed_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )


class ScheduledOperationDetails(proto.Message):
    r"""Details of scheduled operation.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/datatypes/ScheduledOperationDetails

    Attributes:
        day_of_week (google.type.dayofweek_pb2.DayOfWeek):
            Output only. Day of week.
        start_time (google.type.timeofday_pb2.TimeOfDay):
            Output only. Auto start time.
        stop_time (google.type.timeofday_pb2.TimeOfDay):
            Output only. Auto stop time.
    """

    day_of_week: dayofweek_pb2.DayOfWeek = proto.Field(
        proto.ENUM,
        number=1,
        enum=dayofweek_pb2.DayOfWeek,
    )
    start_time: timeofday_pb2.TimeOfDay = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timeofday_pb2.TimeOfDay,
    )
    stop_time: timeofday_pb2.TimeOfDay = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timeofday_pb2.TimeOfDay,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
from google.type import datetime_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.oracledatabase.v1",
    manifest={
        "CloudVmCluster",
        "CloudVmClusterProperties",
        "DataCollectionOptions",
    },
)


class CloudVmCluster(proto.Message):
    r"""Details of the Cloud VM Cluster resource.
    https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/CloudVmCluster/

    Attributes:
        name (str):
            Identifier. The name of the VM Cluster resource with the
            format:
            projects/{project}/locations/{region}/cloudVmClusters/{cloud_vm_cluster}
        exadata_infrastructure (str):
            Required. The name of the Exadata Infrastructure resource on
            which VM cluster resource is created, in the following
            format:
            projects/{project}/locations/{region}/cloudExadataInfrastuctures/{cloud_extradata_infrastructure}
        display_name (str):
            Optional. User friendly name for this
            resource.
        gcp_oracle_zone (str):
            Output only. Google Cloud Platform location
            where Oracle Exadata is hosted. It is same as
            Google Cloud Platform Oracle zone of Exadata
            infrastructure.
        properties (google.cloud.oracledatabase_v1.types.CloudVmClusterProperties):
            Optional. Various properties of the VM
            Cluster.
        labels (MutableMapping[str, str]):
            Optional. Labels or tags associated with the
            VM Cluster.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The date and time that the VM
            cluster was created.
        cidr (str):
            Required. Network settings. CIDR to use for
            cluster IP allocation.
        backup_subnet_cidr (str):
            Required. CIDR range of the backup subnet.
        network (str):
            Required. The name of the VPC network.
            Format:
            projects/{project}/global/networks/{network}
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    exadata_infrastructure: str = proto.Field(
        proto.STRING,
        number=2,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
    )
    gcp_oracle_zone: str = proto.Field(
        proto.STRING,
        number=12,
    )
    properties: "CloudVmClusterProperties" = proto.Field(
        proto.MESSAGE,
        number=6,
        message="CloudVmClusterProperties",
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=7,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=8,
        message=timestamp_pb2.Timestamp,
    )
    cidr: str = proto.Field(
        proto.STRING,
        number=9,
    )
    backup_subnet_cidr: str = proto.Field(
        proto.STRING,
        number=10,
    )
    network: str = proto.Field(
        proto.STRING,
        number=11,
    )


class CloudVmClusterProperties(proto.Message):
    r"""Various properties and settings associated with Exadata VM
    cluster.

    Attributes:
        ocid (str):
            Output only. Oracle Cloud Infrastructure ID
            of VM Cluster.
        license_type (google.cloud.oracledatabase_v1.types.CloudVmClusterProperties.LicenseType):
            Required. License type of VM Cluster.
        gi_version (str):
            Optional. Grid Infrastructure Version.
        time_zone (google.type.datetime_pb2.TimeZone):
            Optional. Time zone of VM Cluster to set.
            Defaults to UTC if not specified.
        ssh_public_keys (MutableSequence[str]):
            Optional. SSH public keys to be stored with
            cluster.
        node_count (int):
            Optional. Number of database servers.
        shape (str):
            Output only. Shape of VM Cluster.
        ocpu_count (float):
            Optional. OCPU count per VM. Minimum is 0.1.
        memory_size_gb (int):
            Optional. Memory allocated in GBs.
        db_node_storage_size_gb (int):
            Optional. Local storage per VM.
        storage_size_gb (int):
            Output only. The storage allocation for the
            disk group, in gigabytes (GB).
        data_storage_size_tb (float):
            Optional. The data disk group size to be
            allocated in TBs.
        disk_redundancy (google.cloud.oracledatabase_v1.types.CloudVmClusterProperties.DiskRedundancy):
            Optional. The type of redundancy.
        sparse_diskgroup_enabled (bool):
            Optional. Use exadata sparse snapshots.
        local_backup_enabled (bool):
            Optional. Use local backup.
        hostname_prefix (str):
            Optional. Prefix for VM cluster host names.
        diagnostics_data_collection_options (google.cloud.oracledatabase_v1.types.DataCollectionOptions):
            Optional. Data collection options for
            diagnostics.
        state (google.cloud.oracledatabase_v1.types.CloudVmClusterProperties.State):
            Output only. State of the cluster.
        scan_listener_port_tcp (int):
            Output only. SCAN listener port - TCP
        scan_listener_port_tcp_ssl (int):
            Output only. SCAN listener port - TLS
        domain (str):
            Output only. Parent DNS domain where SCAN DNS
            and hosts names are qualified. ex:
            ocispdelegated.ocisp10jvnet.oraclevcn.com
        scan_dns (str):
            Output only. SCAN DNS name.
            ex:
            sp2-yi0xq-scan.ocispdelegated.ocisp10jvnet.oraclevcn.com
        hostname (str):
            Output only. host name without domain. format:
            "<hostname_prefix>-" with some suffix. ex: sp2-yi0xq where
            "sp2" is the hostname_prefix.
        cpu_core_count (int):
            Required. Number of enabled CPU cores.
        system_version (str):
            Output only. Operating system version of the
            image.
        scan_ip_ids (MutableSequence[str]):
            Output only. OCIDs of scan IPs.
        scan_dns_record_id (str):
            Output only. OCID of scan DNS record.
        oci_url (str):
            Output only. Deep link to the OCI console to
            view this resource.
        db_server_ocids (MutableSequence[str]):
            Optional. OCID of database servers.
        compartment_id (str):
            Output only. Compartment ID of cluster.
        dns_listener_ip (str):
            Output only. DNS listener IP.
        cluster_name (str):
            Optional. OCI Cluster name.
    """

    class LicenseType(proto.Enum):
        r"""Different licenses supported.

        Values:
            LICENSE_TYPE_UNSPECIFIED (0):
                Unspecified
            LICENSE_INCLUDED (1):
                License included part of offer
            BRING_YOUR_OWN_LICENSE (2):
                Bring your own license
        """
        LICENSE_TYPE_UNSPECIFIED = 0
        LICENSE_INCLUDED = 1
        BRING_YOUR_OWN_LICENSE = 2

    class DiskRedundancy(proto.Enum):
        r"""Types of disk redundancy provided by Oracle.

        Values:
            DISK_REDUNDANCY_UNSPECIFIED (0):
                Unspecified.
            HIGH (1):
                High -  3 way mirror.
            NORMAL (2):
                Normal - 2 way mirror.
        """
        DISK_REDUNDANCY_UNSPECIFIED = 0
        HIGH = 1
        NORMAL = 2

    class State(proto.Enum):
        r"""The various lifecycle states of the VM cluster.

        Values:
            STATE_UNSPECIFIED (0):
                Default unspecified value.
            PROVISIONING (1):
                Indicates that the resource is in
                provisioning state.
            AVAILABLE (2):
                Indicates that the resource is in available
                state.
            UPDATING (3):
                Indicates that the resource is in updating
                state.
            TERMINATING (4):
                Indicates that the resource is in terminating
                state.
            TERMINATED (5):
                Indicates that the resource is in terminated
                state.
            FAILED (6):
                Indicates that the resource is in failed
                state.
            MAINTENANCE_IN_PROGRESS (7):
                Indicates that the resource is in maintenance
                in progress state.
        """
        STATE_UNSPECIFIED = 0
        PROVISIONING = 1
        AVAILABLE = 2
        UPDATING = 3
        TERMINATING = 4
        TERMINATED = 5
        FAILED = 6
        MAINTENANCE_IN_PROGRESS = 7

    ocid: str = proto.Field(
        proto.STRING,
        number=1,
    )
    license_type: LicenseType = proto.Field(
        proto.ENUM,
        number=2,
        enum=LicenseType,
    )
    gi_version: str = proto.Field(
        proto.STRING,
        number=3,
    )
    time_zone: datetime_pb2.TimeZone = proto.Field(
        proto.MESSAGE,
        number=4,
        message=datetime_pb2.TimeZone,
    )
    ssh_public_keys: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )
    node_count: int = proto.Field(
        proto.INT32,
        number=6,
    )
    shape: str = proto.Field(
        proto.STRING,
        number=7,
    )
    ocpu_count: float = proto.Field(
        proto.FLOAT,
        number=8,
    )
    memory_size_gb: int = proto.Field(
        proto.INT32,
        number=9,
    )
    db_node_storage_size_gb: int = proto.Field(
        proto.INT32,
        number=10,
    )
    storage_size_gb: int = proto.Field(
        proto.INT32,
        number=11,
    )
    data_storage_size_tb: float = proto.Field(
        proto.DOUBLE,
        number=12,
    )
    disk_redundancy: DiskRedundancy = proto.Field(
        proto.ENUM,
        number=13,
        enum=DiskRedundancy,
    )
    sparse_diskgroup_enabled: bool = proto.Field(
        proto.BOOL,
        number=14,
    )
    local_backup_enabled: bool = proto.Field(
        proto.BOOL,
        number=15,
    )
    hostname_prefix: str = proto.Field(
        proto.STRING,
        number=16,
    )
    diagnostics_data_collection_options: "DataCollectionOptions" = proto.Field(
        proto.MESSAGE,
        number=19,
        message="DataCollectionOptions",
    )
    state: State = proto.Field(
        proto.ENUM,
        number=20,
        enum=State,
    )
    scan_listener_port_tcp: int = proto.Field(
        proto.INT32,
        number=21,
    )
    scan_listener_port_tcp_ssl: int = proto.Field(
        proto.INT32,
        number=22,
    )
    domain: str = proto.Field(
        proto.STRING,
        number=23,
    )
    scan_dns: str = proto.Field(
        proto.STRING,
        number=24,
    )
    hostname: str = proto.Field(
        proto.STRING,
        number=25,
    )
    cpu_core_count: int = proto.Field(
        proto.INT32,
        number=26,
    )
    system_version: str = proto.Field(
        proto.STRING,
        number=27,
    )
    scan_ip_ids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=28,
    )
    scan_dns_record_id: str = proto.Field(
        proto.STRING,
        number=29,
    )
    oci_url: str = proto.Field(
        proto.STRING,
        number=30,
    )
    db_server_ocids: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=31,
    )
    compartment_id: str = proto.Field(
        proto.STRING,
        number=32,
    )
    dns_listener_ip: str = proto.Field(
        proto.STRING,
        number=35,
    )
    cluster_name: str = proto.Field(
        proto.STRING,
        number=36,
    )


class DataCollectionOptions(proto.Message):
    r"""Data collection options for diagnostics.

    Attributes:
        diagnostics_events_enabled (bool):
            Optional. Indicates whether diagnostic
            collection is enabled for the VM cluster
        health_monitoring_enabled (bool):
            Optional. Indicates whether health monitoring
            is enabled for the VM cluster
        incident_logs_enabled (bool):
            Optional. Indicates whether incident logs and
            trace collection are enabled for the VM cluster
    """

    diagnostics_events_enabled: bool = proto.Field(
        proto.BOOL,
        number=1,
    )
    health_monitoring_enabled: bool = proto.Field(
        proto.BOOL,
        number=2,
    )
    incident_logs_enabled: bool = proto.Field(
        proto.BOOL,
        number=3,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
